@@ -1,3 +1,3 @@
 import ctypes
-so = ctypes.CDLL('./sleep.so')
+so = ctypes.CDLL('sleep.so')
 wait = so.wait
